<?php
/*
Plugin Name: YouTube Video Remover
Description: Removes embedded YouTube videos from recent posts based on user input and checks posts for video content.
Version: 1.4
Author: Botsy AI
*/

// Hook for adding admin menus
add_action('admin_menu', 'youtube_video_remover_menu');

// Action function for above hook
function youtube_video_remover_menu() {
    add_options_page('YouTube Video Remover Settings', 'YouTube Video Remover', 'manage_options', 'youtubevideoremover', 'youtube_video_remover_settings_page');
}

// Displays the page content for the YouTube Video Remover submenu
function youtube_video_remover_settings_page() {
    ?>
    <div class="wrap">
        <h1>YouTube Video Remover</h1>
        <form method="post">
            <input type="hidden" name="action" value="check_youtube_videos"/>
            <?php submit_button('Check Posts for YouTube Videos') ?>
        </form>
        <form method="post">
            <label for="number_of_videos">Number of videos to remove:</label>
            <select name="number_of_videos" id="number_of_videos">
                <option value="1">1</option>
                <option value="10">10</option>
                <option value="25">25</option>
                <option value="50">50</option>
                <option value="100">100</option>
            </select>
            <input type="hidden" name="action" value="remove_youtube_videos"/>
            <?php submit_button('Remove YouTube Videos') ?>
        </form>
        <?php
        if (isset($_POST['action']) && $_POST['action'] === 'remove_youtube_videos') {
            $number_of_videos = intval($_POST['number_of_videos']);
            remove_youtube_videos($number_of_videos);
        } elseif (isset($_POST['action']) && $_POST['action'] === 'check_youtube_videos') {
            check_youtube_videos();
        }
        ?>
    </div>
    <?php
}

// Function to check posts for YouTube videos
function check_youtube_videos() {
    $args = array(
        'post_type' => 'post',
        'posts_per_page' => -1, // Get all posts
        'orderby' => 'date',
        'order' => 'DESC'
    );

    $recent_posts = get_posts($args);
    $post_with_videos = 0;
    $post_without_videos = 0;

    foreach ($recent_posts as $post) {
        $pattern = '/<iframe.*?src=".*?(youtube\.com|youtu\.be).*?".*?<\/iframe>/i';

        // Check if the post has a YouTube video
        if (preg_match_all($pattern, $post->post_content, $matches)) {
            $post_with_videos += count($matches[0]);  // Count all videos in the post
        } else {
            $post_without_videos++;
        }
    }

    echo "<div><strong>Check Result:</strong> Posts with videos: $post_with_videos; Posts without videos: $post_without_videos</div>";
}

// Function to remove YouTube videos and count posts
function remove_youtube_videos($number_of_videos) {
    $args = array(
        'post_type' => 'post',
        'posts_per_page' => -1, // Get all posts
        'orderby' => 'date', // Order by date
        'order' => 'DESC' // From most recent to oldest
    );

    $recent_posts = get_posts($args);
    $post_with_videos = 0;
    $post_without_videos = 0;
    $videos_removed = 0;
    $affected_posts = array();

    foreach ($recent_posts as $post) {
        if ($videos_removed >= $number_of_videos) {
            break; // Stop if we've removed the desired number of videos
        }

        $pattern = '/<iframe.*?src=".*?(youtube\.com|youtu\.be).*?".*?<\/iframe>/i';

        if (preg_match_all($pattern, $post->post_content, $matches)) {
            $post_with_videos += count($matches[0]); // Count all videos in the post
            $videos_removed += count($matches[0]); // Count all videos removed

            // Get the post URL and title
            $post_url = get_permalink($post->ID);
            $post_title = get_the_title($post->ID);

            // Store necessary data of affected posts
            $affected_posts[] = array(
                'ID' => $post->ID,
                'title' => $post_title,
                'url' => $post_url
            );

            $replacement = '';
            wp_update_post(array(
                'ID' => $post->ID,
                'post_content' => preg_replace($pattern, $replacement, $post->post_content),
            ));
        } else {
            $post_without_videos++;
        }
    }

    // Display results
    echo "<div><strong>Result:</strong> Posts with videos: $post_with_videos; Posts without videos: $post_without_videos; Videos removed: $videos_removed</div>";

    if (count($affected_posts) > 0) {
        echo "<div><strong>Affected posts:</strong><ul>";
        foreach ($affected_posts as $post) {
            echo "<li><a href='" . esc_url($post['url']) . "' target='_blank'>" . esc_html($post['title']) . "</a> (ID: " . intval($post['ID']) . ")</li>";
        }
        echo "</ul></div>";
    }
}
?>